<?php
/*
Plugin Name: Covert Action Bar
Description: Simple plugin that generates pop-up blocker styled ads on your blog, grabbing your readers attention and "forcing" them to click your links. <a href="http://covertactionbar.com/upgrade" target="_blank">Click here to upgrade to the Pro version</a>
Version: 1.3
Author: IM Wealth Builders Ltd
Author URI: http://imwealthbuilders.com/newplugins

Copyright 2012  IM Wealth Builders

*/

define('IMWB_CAB_VERSION', '1.3');
define('IMWB_CAB_FOLDER', 'covertactionbar');
define('IMWB_CAB_PREFIX', 'imwb_');

/**
 * This is where you add comments for your plugin class 
 * @author John Merrick
 */
class IMWB_Covert_Action_Bar {
	/**
	 * This value will be used for 
	 * - the gettext textdomain 
	 * - the subfolder when adding scripts and styles
	 * - the handle for scripts and styles
	 * Please make sure that this value corresponds to the folder name where your plugin resides.
	 * @var string 
	 */
	 var $plugin_name = "";
	 var $plugin_url = "";
	 var $update;
		
	/**
	 * The constructor is executed when the class is instatiated and the plugin gets loaded.
	 * @return void
	 */
	function IMWB_Covert_Action_Bar() {
	
	   $this->plugin_name = IMWB_CAB_PREFIX.IMWB_CAB_FOLDER;
	
   	// Hack to avoid firing on Admin Login or Registration page
   	if ( in_array( $GLOBALS['pagenow'], array( 'wp-login.php', 'wp-register.php' ) ) )
   	   return;

   	$this->plugin_url = plugins_url(basename( dirname( __FILE__)));
		
      if(is_admin()){
         // Get Update Information
      	$this->get_update_info();
     		add_action('after_plugin_row', array(&$this, 'check_for_update'));
      	add_action('wp_ajax_'.$this->plugin_name.'_clear_cookie', array(&$this, 'clear_cookie'));
      	add_action('admin_menu', array(&$this,'init_admin_menu'));
      	add_action( "admin_print_scripts-settings_page_imwb_covertactionbar-admin-menu", array(&$this,'init_admin_scripts') );
      }
      else {
      	add_action('wp_print_scripts', array(&$this, 'init_scripts'),20);
      	add_action('wp_head', array(&$this, 'load_script'));
      }
      
		add_action('init', array(&$this, 'init_styles'), 20);
		add_action('wp_print_scripts', array(&$this, 'init_scripts'));
		add_action('wp_head', array(&$this, 'load_script'));
		}
	
	//Returns an array of admin options
	function get_admin_options() {
		$adminOptions = array('bar_text' => 'This is the sample action bar text',
		                      'bar_url' => 'http://yourdomain.com',
		                      'bar_delay' => '0',
		                      'show_samewindow' => "true",
		                      'where_shown' => 'E',
		                      'bar_reshow_days' => '0',
		                      'bar_reshow_hours' => '0',
		                      'play_sound' => "true");
			
		$devOptions = get_option($this->plugin_name."-AdminOptions");
		if (!empty($devOptions)) {
			foreach ($devOptions as $key => $option)
				$adminOptions[$key] = $option;
		}				
		update_option($this->plugin_name."-AdminOptions", $adminOptions);
		return $adminOptions;
	}
	
	/**
	 * Loading the frontend javascripts
	 * /scripts/script.js from the plugin directory. By default the script is enqueued 
	 * in the page footer for faster page loading. 
	 * @return void
	 */
	function init_scripts() {
		// Only enqueue scripts on frontend. 
		wp_enqueue_script('jquery');
      wp_enqueue_script($this->plugin_name . '-script', $this->plugin_url.'/scripts/script.js', array('jquery'), '1.1');
	}
	
   /**
    * Loading the Admin side javascripts
    * /scripts/admin_options_page.js from the plugin directory. 
    * @return void
    */
	
   function init_admin_scripts() {
   	// Only enqueue scripts on frontend. 
   	wp_enqueue_script('jquery');
   	
      wp_enqueue_script('imwb_cab_admin_options_script', $this->plugin_url.'/scripts/admin_options_page.js', array('jquery'), '1.1');
   
   	wp_localize_script('imwb_cab_admin_options_script', 'IMWB_CAB_Ajax', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ), 'nonce' => wp_create_nonce( 'imwb_cab_clear_cookie_nonce' ), 'plugin_url' => $this->plugin_url, 'wp_root' => $this->get_wp_root_path() ) );
   }
	
	/**
	 * Loading the stylesheet for this plugin. 
	 * @return void
	 */
	function init_styles() {

		if(!is_admin()) {
			wp_enqueue_style($this->plugin_name . '-stylesheet', $this->plugin_url.'/styles/cabar.css', array(), '1.1', 'all');		
		}
		else if(is_admin()) {
		   wp_enqueue_style($this->plugin_name . '-stylesheet', $this->plugin_url.'/styles/admin_options_page.css', array(), '1.1', 'all');
		}
	}
	
	/**
	 * Adds a new menu with the name "My Admin Menu" and let's anyone that
	 * can publish posts be able to use it. 
	 * @return void
	 */
	function init_admin_menu() {
		// Add the menu page
		add_options_page('Covert Action Bar Admin Menu', 'Covert Action Bar', 'manage_options', $this->plugin_name . '-admin-menu', array(&$this,'main_menu_page'));
	}

	/**
	 * This function will be executed when the admin page is to be loaded
	 * @return void
	 */
	function main_menu_page() {
		$devOptions = $this->get_admin_options();
		// Include the HTML from a separate file to keep the plugin class clean
		require "pages/admin_options_page.php";
	}
	
	function load_script() {
		$devOptions = $this->get_admin_options();
		   
	   // Make sure we should be shown on this page
	   if($devOptions['where_shown'] == "F" && !is_front_page())
	   	return true;
	   	
   	if($_COOKIE['imwb_cab_show'] == 'N' || $_COOKIE['imwb_cab_reshow'] == 'N')	             
	   	return true;
	   	
	   if(!is_admin()) {
		   wp_enqueue_script('jquery');
		   $cabwavfile = $this->plugin_url.'/cabar.mp3';
		   $cabgiffile = $this->plugin_url.'/images/warning.gif';
		   
         if ($devOptions['show_samewindow'] == "true")
            $cablinkwindow = "_self";
         else
            $cablinkwindow = "_blank";
?>
	<script type="text/javascript">
      jQuery(document).ready(function($) {
         // $() will work as an alias for jQuery() inside of this function
         if(cabCookie('imwb_cab_show') == 'N' || cabCookie('imwb_cab_reshow') == 'N')
            return;
            
         setTimeout(imwb_show_cab, <?php echo $devOptions["bar_delay"]*1000;?>);

         $('.imwb_cabar').live('click', function() {
            cabCookie('imwb_cab_show', 'N', <?php echo ($devOptions["bar_reshow_days"]*24);?>,'<?php echo COOKIEPATH;?>');
            window.open("<?php echo $devOptions["bar_url"];?>","<?php echo $cablinkwindow;?>");
            return true;
         });	
            
         function imwb_show_cab() {
         
            if(typeof window.IMWB_CMB_Activated !== "undefined") 
               return;
         
            jQuery("body").prepend('<div class="imwb_cabar"><img src="<?php echo $cabgiffile;?>"><p><?php echo do_shortcode($devOptions["bar_text"]);?></p><?php if ($devOptions['play_sound'] == "true") { echo '<object width="0" height="0" id="player" classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000"><param name="movie" value="'.$this->plugin_url.'/JFPlayIt.swf?url='.$cabwavfile.'"><embed src="'.$this->plugin_url.'/JFPlayIt.swf?url='.$cabwavfile.'" name="player" width="0" height="0" type="application/x-shockwave-flash"></embed></object>';}?></div>');
            
            cabCookie('imwb_cab_reshow', 'N', <?php echo ($devOptions["bar_reshow_hours"]);?>,'<?php echo COOKIEPATH;?>');
         }
      });
	</script>
<?php
      }
	}
	
	function get_wp_root_path()
	{
	    $path = parse_url(get_bloginfo('wpurl'), PHP_URL_PATH);
	    if(!isset($path))
	       return '/';
	    else
	  	    return $path;
	}
	
	function get_update_info() {
      // Include Update Class
      require_once('covertactionbar-admin-update.php');
      
      // Initialize Update Object
      $this->update = new IMWB_Covert_Action_BarUpdate($this->plugin_name);	
	}
	
	function check_for_update($plugin)
	{
		if(strpos($plugin, IMWB_CAB_FOLDER.'/') !== false)
			$this->update->getUpdateInfo(1);
	}
	
	// AJAX Functions
	function clear_cookie() {
	
		$nonce = $_POST['nonce'];
	
	   if ( ! wp_verify_nonce( $nonce, 'imwb_cab_clear_cookie_nonce' ) )
	      die ( 'Busted!');
	    
		setcookie('imwb_cab_show','Y',time()-8640000,COOKIEPATH);
		setcookie('imwb_cab_reshow','Y',time()-8640000,COOKIEPATH);
		
		echo 'OK';
		
		die();
	}
}

/**
 * Register the plugin
 * @todo Change 'Plugin_Boilerplate' in the anonymous function to the name of the class
 */
add_action("init", create_function('', 'new IMWB_Covert_Action_Bar();'));
